<?php

class SMW_Controllers_Items_Type_Images extends SMW_Controllers_Items_Item {
    private static $instance;
    private function __construct() {
        $this->db = $this->getItemDb('images');
        $this->buy_links = SMW::getHelper('buy-links');
        $this->lightbox = SMW::getHelper('lightbox');
        $this->url = SMW::getHelper('url');
    }
    public function itemDisplay( $image, $thumb_size = 'thumb_url', $viewable_size = 'large_url', $video_size = 'video640_url') {
        $new_image['Caption'] = $this->getCaption($image['caption']);
        $new_image['ThumbURL'] = $this->url->finalURL($image[$thumb_size]);
        $new_image['BuyLink'] = $this->buy_links->image( $image );
        
        if($image[$video_size]) {
            $wh = $this->height_width($image['width'],$image['height'],$video_size);
            $new_image['Height'] = $wh['height'];
            $new_image['Width'] = $wh['width'];
            $new_image['Type'] = 'video';
            $new_image['UsableURL'] = $this->url->videoURL($image,$wh['width'],$wh['height'],$video_size);
        } else {
            $new_image['Type'] = 'image';
            $new_image['UsableURL'] = $this->url->finalURL($image[$viewable_size]);
        }
        $new_image['Lightbox'] = $this->lightbox->code('images', $new_image );
        return $new_image;
    }
    public function getCaption( $caption ) {
        if(get_option('smw_caption_frontend') == 0) {
            $caption_final = '';
        } else {
            $caption_final = htmlspecialchars(stripcslashes($caption),ENT_QUOTES);
        }
        return $caption_final;
    }
    public function addGallery( $idKey ) {
        $this->addGallery( $idKey );
    }
    public function height_width($width, $height, $video_size) {
        $video_size = str_replace(array('video','_url'),'',$video_size);
        $hw_var['width'] = $width;
        $hw_var['height'] = $height;

        if($hw_var['width'] >= $hw_var['height']) {
            $hw_ratio = $video_size/$hw_var['width'];
            $hw_final['width'] = $video_size;
            $hw_final['height'] = number_format($hw_var['height'] * $hw_ratio,0);
        } else {
            $hw_ratio = $video_size/$hw_var['height'];
            $hw_final['height'] = $video_size;
            $hw_final['width'] = number_format($hw_var['width'] * $hw_ratio,0);
        }
        return $hw_final;
    }
    public function getRand( $id, $number, $thumb_size, $viewable_size ) {
        $images = $this->db->getRand( $id, $number );
        foreach($images as $key => $image) {
            $rand_images[$key] = $this->itemDisplay( $image, $thumb_size, $viewable_size );
        }
        return $rand_images;
    }
    public function setIdKey( $idKey ) {
        $this->idKey = $idKey;
        return $this->idKey;
    }
    public static function getInstance() {
        if(!isset(self::$instance)) {
            $className = __CLASS__;
            self::$instance = new $className;
        }
        return self::$instance;
    }
    public function getAll( $id ) {
        return $this->db->selectAll( $id );
    }
    public function imageEXIFAjax() {
        $this->image_exif = $this->db->getExif( $_POST['id'], $_POST['key'] );
        $this->filename = $_POST['filename'];
        
        SMW::getBlock('admin/galleries/edit/exif');
        die();
    }
    public function imageHideAjax() {
        $this->db->hideItem( $_POST['id'] );
        //print_r($_POST);
        if($_POST['hidden'] == 1) {
            echo '<button class="button-secondary" imagehide="0" key="'.$_POST['key'].'" id="'.$_POST['id'].'">Hide Image</button>';
            echo '<h3>Not Hidden</h3>';
        } else {
            echo '<button class="button-secondary" imagehide="1" key="'.$_POST['key'].'" id="'.$_POST['id'].'">Show Image</button>';
            echo '<h3>Hidden</h3>';
                

        }
        
        die();
    }
    public function caption_save_callback() {
        $remove_slashes = stripslashes($_POST['caption']);
        $slashed = addslashes($remove_slashes);
        $args['wordpress'] = array(
            'caption' => $slashed 
        );
        $args['service'] = array(
            'ImageID' => $_POST['image_id'],
            'Caption' => stripslashes($_POST['caption'])
        );
        $args['where'] = array(
            'image_id' => $_POST['image_id']
        );
        $response = $this->db->updateItem( $args );
        echo stripslashes($response['caption']);
        die();
    }
    public function imagesAjax() {
        //$self = SMW::getItem('images');
        //$self->getAll($_POST['id']);
        
        if(isset($_REQUEST['page'])) {
            $this->currentPage = $_REQUEST['page'];
        } else {
            $this->currentPage = 1;
        }
        
        $imageNumber = $_POST['imagesNumber'];
		
        $imageCount = $_POST['imageCount'];
        //$ajaxurl = $_POST['pass_ajaxurl'];

        $this->pagination = new SMW_Helpers_Pagination($this->currentPage, $imageNumber, $imageCount);

        $this->totalPages = $this->pagination->total_pages();
        
        $this->images_array = $this->db->selectAll( $_POST['id'] );
        
        if($imageNumber != 'All') {
            $this->paged_images = array_slice($this->images_array,$this->pagination->offset(),$imageNumber);			
        } else {
            $this->paged_images = $this->images_array;	
        }
        
        //$this->paged_images = $_SESSION['images'];
        SMW::getBlock('admin/galleries/edit/images');
        die();
    }
    public function getCount( $id = false, $type = false ) {
        return $this->db->getCount( $id, $type );
    }
    public function getPage( $args ) {
        return $this->db->getPage( $args );
    }
    public function getItem( $id ) {
        return $this->db->selectItem( $id );
    }
    public function getUrl() {
        
    }
    public function getThumbUrl() {
        
    }
}
